==> cms-db_v0.5.1.tar.gz: admin/template.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('template');
?>
<?php
if ($_POST['button']) {
//START
$filename = "../data/template.tpl";
$content = $_POST['content'];
$content = stripslashes($content);
if (is_writable($filename)) {

   if (!$handle = fopen($filename, "w")) {
         print "<link rel=\"stylesheet\" type=\"text/css\" href=\"style.css\"><h1>Fehler</h1><br /><br />Kann die Datei $filename nicht &ouml;ffnen<br /><br /><br /><a href=\"JavaScript:history.back()\">zur&uuml;ck</a>";
         exit;
   }

   if (!fwrite($handle, $content)) {
       print "<link rel=\"stylesheet\" type=\"text/css\" href=\"style.css\"><h1>Fehler</h1><br /><br />Kann in die Datei $filename nicht schreiben<br /><br /><br /><a href=\"JavaScript:history.back()\">zur&uuml;ck</a>";
       exit;
   }

   header("Location:template.php?saved=yes&wysiwyg=".$_POST['wysiwyg']."&".SID);

   fclose($handle);

} else {
   print "<link rel=\"stylesheet\" type=\"text/css\" href=\"style.css\"><h1>Fehler</h1><br /><br />Die Datei $filename ist nicht schreibbar<br /><br /><br /><a href=\"JavaScript:history.back()\">zur&uuml;ck</a>";
}
//ENDE
} else {
if (!isset($_GET['wysiwyg'])) {
	$wysiwyg = 'no';
} else {
	$wysiwyg = $_GET['wysiwyg'];
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>CMS Inhalt</title>
<link rel="stylesheet" type="text/css" href="style.css">
<script language="JavaScript">
<!--
function addPage(text) {
 //text = text.replace(/\//g,"%2F");
 //text = text.replace(/&/g,"&amp;");
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
function addFile(text) {
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
//-->
</script>
<noscript>Bitte aktivieren Sie JavaScript, um die Funktion zum Einf&uuml;gen von Adressen bzw. den WYSIWYG-Editor zu nutzen.</noscript>
<?php
if ($wysiwyg == 'yes') {
?>
<script language="javascript" type="text/javascript" src="tinymce/jscripts/tiny_mce/tiny_mce.js"></script>
<script language="javascript" type="text/javascript">
	tinyMCE.init({
		mode : "textareas",
		theme : "advanced",
		skin : "o2k7",
		plugins : "table,advhr,advimage,advlink,insertdatetime,media,searchreplace,contextmenu,paste,fullscreen,style,inlinepopups,preview,safari,fullpage",
		theme_advanced_buttons1_add : "fontselect,fontsizeselect",
		theme_advanced_buttons2_add : "|,insertdate,inserttime,|,forecolor,backcolor",
		theme_advanced_buttons2_add_before: "cut,copy,paste,pastetext,pasteword,|,search,replace,|",
		theme_advanced_buttons3_add_before : "tablecontrols,|",
		theme_advanced_buttons3_add : "media,advhr,|,fullscreen,|,styleprops,|,fullpage",
		theme_advanced_toolbar_location : "top",
		theme_advanced_toolbar_align : "left",
		theme_advanced_path_location : "bottom",
		/*content_css : "/example_data/example_full.css",*/
	    plugin_insertdate_dateFormat : "%d.%m.%Y",
	    plugin_insertdate_timeFormat : "%H:%M:%S",
		extended_valid_elements : "hr[class|width|size|noshade],font[face|size|color|style],span[class|align|style],textarea[cols|rows|class|id],script[language|type]",
		theme_advanced_resize_horizontal : true,
		theme_advanced_resizing : true,
		apply_source_formatting : true,
		convert_urls : false,
		doctype : '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">',
		file_browser_callback : "fileBrowserCallBack",
		language : "de"
	});

	function fileBrowserCallBack(field_name, url, type, win) {
         	if (type == "file") {
                 	//HTML-Datei
                         pagemanager = window.open('http://<?php echo $_SERVER['SERVER_NAME'].ereg_replace("template.php?(.*)","",$_SERVER["REQUEST_URI"]) ?>pagemanager.php','pagemanager','width=330,height=300,left='+(screen.availWidth/2-50)+',top='+(screen.availHeight/2-50)+',scrollbars=yes');
                         pagemanager.field_name = field_name;
                         pagemanager.win = win;
                 } else if (type == "image") {
                 	//Bild
                         filemanager = window.open('http://<?php echo $_SERVER['SERVER_NAME'].ereg_replace("template.php?(.*)","",$_SERVER["REQUEST_URI"]) ?>filemanager.php','filemanager','width=330,height=300,left='+(screen.availWidth/2-50)+',top='+(screen.availHeight/2-50)+',scrollbars=yes');
                         filemanager.field_name = field_name;
                         filemanager.win = win;
                 } else if (type == "media") {
                 	//Media
                         filemanager = window.open('http://<?php echo $_SERVER['SERVER_NAME'].ereg_replace("template.php?(.*)","",$_SERVER["REQUEST_URI"]) ?>filemanager.php','filemanager','width=330,height=300,left='+(screen.availWidth/2-50)+',top='+(screen.availHeight/2-50)+',scrollbars=yes');
                         filemanager.field_name = field_name;
                         filemanager.win = win;
                 } else {
                 	//Fehler
                         alert("Ein Fehler ist aufgetreten!\n\nUmgebungsvariablen:\nFeldname: " + field_name + "\nURL: " + url + "\nDatei-Typ: " + type + "\nFenster: " +win);
                 };
		// This is where you insert your custom filebrowser logic
		//alert("Example of filebrowser callback: field_name: " + field_name + ", url: " + url + ", type: " + type);

		// Insert new URL, this would normaly be done in a popup
		//win.document.forms[0].elements[field_name].value = "someurl.htm";
	}
</script>
<?php
}
?>
</head>
<body>

<h1>Template/Design editieren</h1>
<h2>Editieren</h2>
<p>
	<form action="template.php?<?php echo SID ?>" method="post">
		<?php
		if ($wysiwyg == 'no') {
			echo '<a href="template.php?wysiwyg=yes&amp;'.SID.'">WYSIWYG-Editor verwenden</a> (nicht empfohlen)<br />';
		} elseif ($wysiwyg == 'yes') {
			echo '<a href="template.php?wysiwyg=no&amp;'.SID.'">Text-Editor verwenden</a> (empfohlen)<br />';
		}
		?>
		<input type="hidden" name="wysiwyg" value="<?php echo $wysiwyg ?>" />
		<textarea id="content" name="content" cols="80" rows="20" style="border: 1px solid #BFBFBF; font-family: Verdana; font-size: 12px;"><?php
  function GetContent($file)
  {
    if(!file_exists($file)) {
      $content = 'Fehler: Die Datei "'.$file.'" ist nicht vorhanden!';
      return $content;
    } else {
      $content = implode("", file($file));
      //START "<" + ">" FIX
      $content = htmlentities($content);
      //ENDE "<" + ">" FIX
      return $content;
    }
  }
echo GetContent("../data/template.tpl");
?></textarea><br />
		<input type="submit" name="button" value="Speichern...">
         </form>
</p>
<p>
	Es k&ouml;nnen Variablen verwendet werden, mehr dazu <a href="variablen.php?<?php echo SID ?>">hier</a>.
</p>
<p>
<?php
if($_GET['saved'] == "yes") {
	echo "\tDas Template wurde gespeichert!";
} else {
	echo "&nbsp;";
}
?>
</p>
<?php
if ($wysiwyg == 'no') {
?>
<h2>Adresse einf&uuml;gen</h2>
<h3>Seite</h3>
<p>
<?php
include ('../data/settings/url.inc.php');
function createPageOverview($urlbefore, $urlafter, $ordner, $count = 0, $sub = FALSE) {
  $vorhanden = 0;
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
        if(is_dir($ordner."/".$file)) {
          $dirs[] = $ordner."/".$file;
		  $vorhanden = 1;
        } else {
		  if ($file != '01,Home') {
		    $files[] = $file;
			$vorhanden = 1;
		  }
        }
    }
  }
  if ($vorhanden == 1) {
    echo '<ul>';
  }
  $replace1 = array('%2F','%2C');
  $replace2 = array('/',',');
  if($dirs) {
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      echo '<li><a href="#" onclick="addPage(\''.$urlbefore.str_replace($replace1, $replace2, urlencode(substr($ordner,12))).'/'.str_replace($replace1, $replace2, urlencode($file)).'/01,Home'.$urlafter.'\')">'.htmlentities($show,ENT_QUOTES).'</a>';
      createPageOverview($urlbefore, $urlafter, $dir, $count+1, TRUE, $file);
	  echo '</li>';
    }
  }
  if($files) {
    natcasesort($files);
    foreach ($files as $file) {
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      $pos = strpos($file, ".DEL");
      echo '<li><a href="#" onclick="addPage(\''.$urlbefore.str_replace($replace1, $replace2, urlencode(substr($ordner,12))).'/'.str_replace($replace1, $replace2, urlencode($file)).$urlafter.'\')">'.htmlentities($show,ENT_QUOTES).'</a></li>';
    }
  }
  closedir($handle);
  if ($vorhanden == 1) {
    echo '</ul>';
  }
}
createPageOverview($urlbefore, $urlafter, "../data/pages");
?>
</p>
<h3>Datei</h3>
<p>
<?php
if ($handle = opendir('../data/files')) {
while (false !== ($file = readdir($handle))) {
 if($file != "." && $file != "..") {
   echo '<a href="JavaScript:addFile(\''.$urlabsolute.'/data/files/'.$file.'\')">'.$file.'</a><br />';
 }
}
closedir($handle);
}
?>
</p>
<?php
}
?>

</body>
</html>
<?php
}
?>

==> cms-db_v0.6.tar.gz: admin/template.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('template');
include('locale.inc.php');
$locale = new LocalizingClass('edit');
?>
<?php
if ($_POST['button']) {
//START
$filename = "../data/template.tpl";
$content = $_POST['content'];
$content = stripslashes($content);
if (is_writable($filename)) {

   if (!$handle = fopen($filename, "w")) {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-open-file',true), $filename), 'template.php?'.SID);
   }

   if (!fwrite($handle, $content)) {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-write-file',true), $filename), 'template.php?'.SID);
   }

   header('Location:template.php?saved=yes&'.SID);

   fclose($handle);

} else {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-fileperms',true), $filename), 'template.php?'.SID);
}
//ENDE
} else {
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_template') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<script type="text/javascript">
<!--
function addPage(text) {
 //text = text.replace(/\//g,"%2F");
 //text = text.replace(/&/g,"&amp;");
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
function addFile(text) {
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
//-->
</script>
<noscript><noscript><?php locale('desc_javascript') ?></noscript></noscript>
</head>
<body>

<h1><?php locale('desc_template') ?></h1>
<p>
	<form action="template.php?<?php echo SID ?>" method="post">
		<textarea id="content" name="content" cols="80" rows="20" style="border: 1px solid #BFBFBF; font-family: Verdana; font-size: 12px;"><?php
include('getcontent.inc.php');
echo GetContent("../data/template.tpl");
?></textarea><br />
		<input type="submit" name="button" value="<?php locale('button_save') ?>">
         </form>
</p>
<p>
	<?php locale('desc_variables') ?>
	<a href="variables.php?<?php echo SID ?>"><?php locale('link_variables') ?></a>
</p>
<p>
<?php
if($_GET['saved'] == "yes") {
	locale('desc_savedtpl');
} else {
	echo '&nbsp;';
}
?>
</p>
<h2><?php locale('desc_insert-url') ?></h2>
<h3><?php locale('desc_insert-page') ?></h3>
<p>
<?php
include('../data/settings/url.inc.php');

include ('../functions_url.inc.php');
function createPageOverview($urlbefore, $urlafter, $ordner, $count = 0, $sub = FALSE) {
  $handle = opendir($ordner);
  while (false !== ($file = readdir($handle))) {
    if($file != "." && $file != "..") {
      if(is_dir($ordner."/".$file)) {
        $dirs[] = $ordner."/".$file;
      }
    }
  }
  closedir($handle);
  if ($dirs) {
    echo '<ul>';
    $replace1 = array('%2F','%2C');
    $replace2 = array('/',',');
    natcasesort($dirs);
    foreach($dirs as $dir) {
      $file = str_replace($ordner."/","",$dir);
      $show = substr($file, 3);
      $show = str_replace("_"," ",$show);
      $show = str_replace("SLASH","/",$show);
      $show = str_replace("AND" ,"&", $show);
      echo '<li><a href="#" onclick="addPage(\''.$urlbefore.get_short_url(substr($ordner,13).'/'.$file.'/01,Home').$urlafter.'\')">'.$show.'</a>';
      createPageOverview($urlbefore, $urlafter, $dir, $count+1, TRUE, $file);
	  echo '</li>';
    }
    echo '</ul>';
  }
}
createPageOverview($urlbefore, $urlafter, "../data/pages");
?>
</p>
<h3><?php locale('desc_insert-file') ?></h3>
<p>
<?php
if ($handle = opendir('../data/files')) {
while (false !== ($file = readdir($handle))) {
 if($file != "." && $file != "..") {
   echo '<a href="JavaScript:addFile(\''.$urlabsolute.'/data/files/'.$file.'\')">'.$file.'</a><br />';
 }
}
closedir($handle);
}
?>
</p>

</body>
</html>
<?php
}
?>
